@@ -2,7 +2,7 @@ package Outthentic::DSL;
 
 use strict;
 
-our $VERSION = '0.1.0';
+our $VERSION = '0.1.1';
 
 use Carp;
 use Data::Dumper;
@@ -10,6 +10,7 @@ use Outthentic::DSL::Context::Range;
 use Outthentic::DSL::Context::Default;
 use Outthentic::DSL::Context::TextBlock;
 use File::Temp qw/ tempfile /;
+use JSON;
 
 $Data::Dumper::Terse=1;
 
@@ -61,6 +62,7 @@ sub new {
         output => $output||'',
         match_l => 40,
         stream => {},
+        languages => {},
         %{$opts},
     }, __PACKAGE__;
 
@@ -87,6 +89,7 @@ sub create_context {
     }
 
     $self->{original_context} = [@original_context];
+
     $self->{current_context} = [@original_context];
 
     $self->add_debug_result('context populated') if $self->{debug_mod} >= 2;
@@ -102,7 +105,7 @@ sub reset_captures {
 
     my $self = shift;
     $self->{captures} = [];
-
+    unlink $self->{cache_dir}."/captures.json" if -f $self->{cache_dir}."/captures.json";
 }
 
 sub reset_succeeded {
@@ -253,6 +256,15 @@ sub check_line {
 
     $self->{captures} = [ @captures ];
 
+    if ($self->{cache_dir}){
+      open CAPTURES, '>', $self->{cache_dir}.'/captures.json' 
+        or confess "can't open ".($self->{cache_dir})."captures.json to write $!";
+      print CAPTURES encode_json($self->{captures});
+      $self->add_debug_result("CAPTURES saved at ".$self->{cache_dir}.'/captures.json')
+        if $self->{debug_mod} >= 1;
+      close CAPTURES;
+    }
+
     # update context
     if ( $self->{within_mode} and $status ){
         $self->{current_context} = [@context_new];
@@ -348,6 +360,12 @@ sub validate {
             next LINE;
         }
 
+        if ($l=~ /^\s*assert:\s(\S+)\s+(.*)$/) {
+            $self->add_debug_result("assert found: $1,$2") if $self->{debug_mod} >= 2;
+            $self->add_result({ status => $1 , message => $2 });
+            next LINE;
+        }
+
         if ($l=~ /^\s*between:\s+(.*)/) { # set new context
             
             $self->{context_modificator} = Outthentic::DSL::Context::Range->new($1);
@@ -476,7 +494,7 @@ sub handle_code {
 
         eval "package main; $code;";
         confess "eval error; sub:handle_code; code:$code\nerror: $@" if $@;
-        $self->add_debug_result("handle_code OK. $code") if $self->{debug_mod} >= 3;
+        $self->add_debug_result("code OK. single line. code: $code") if $self->{debug_mod} >= 3;
 
     } else {
 
@@ -484,28 +502,68 @@ sub handle_code {
 
         my $code_to_print = join "\n", map { my $v=$_; $i++; "[$i] $v" }  @$code;
 
-        if ($code->[1]=~s/^!(.*)//){
+        if ($code->[0]=~s/^\!(.*)//){
 
           my $ext_runner = $1;
 
-          my ($fh, $source_file) = tempfile( DIR => '/tmp' );
+          my $language = (split /\\/, $ext_runner)[-1];
 
-          shift @$code;
+          if ($language eq 'perl'){
 
-          my $code_to_eval = join "\n", @$code;
+              shift @$code;
+              my $code_to_eval = join "\n", @$code;
+              eval "package main; $code_to_eval";
+              confess "eval error; sub:handle_code; code:\n$code_to_print\nerror: $@" if $@;
+              $self->add_debug_result("code OK. inline(perl). $code_to_eval") if $self->{debug_mod} >= 3;
 
-          print $fh $code_to_eval;
-          close $fh;
+          }else{
 
-          system("$ext_runner $source_file 2>$source_file.err 1>$source_file.out");  
+            my $source_file = File::Temp->new( DIR => $self->{cache_dir} , UNLINK => 0 );
 
-          $self->add_debug_result("handle_external_code OK. $code_to_eval") if $self->{debug_mod} >= 3;
-          $self->add_debug_result("handle_external_code OK. multiline. $code_to_eval") if $self->{debug_mod} >= 3;
+            shift @$code;
 
-          unless ($ENV{outth_dls_keep_ext_source_code}){
-            unlink("$source_file.out");
-            unlink("$source_file.err");
-            unlink("$source_file");
+            my $code_to_eval = join "\n", @$code;
+
+            open SOURCE_CODE, '>', $source_file or die "can't open source code file $source_file to write: $!";
+
+            print SOURCE_CODE $code_to_eval;
+
+            close SOURCE_CODE;
+
+            if ($language eq 'bash'){
+
+              if ($self->{languages}->{$language}){
+                $ext_runner = "bash -c '".($self->{languages}->{$language})." && source $source_file'";
+              }else{
+                $ext_runner = "bash -c 'source $source_file'";
+              }
+
+            }else{
+              $ext_runner.= ' '.$self->{languages}->{$language} if $self->{languages}->{$language};
+              $ext_runner.=' '.$source_file;
+            }
+
+            my $st = system("$ext_runner 2>$source_file.err 1>$source_file.out");  
+
+            if ($st != 0){
+              confess "$ext_runner failed, see $source_file.err for detailes";
+            }
+
+            $self->add_debug_result("code OK. inline. $ext_runner") if $self->{debug_mod} >= 2;
+
+            open EXT_OUT, "$source_file.out" or die "can't open file $source_file.out to read: $!";
+
+            while (my $s = <EXT_OUT>){
+              print $s;
+            }
+
+            close EXT_OUT;
+
+              unless ($ENV{outth_dls_keep_ext_source_code}){
+                unlink("$source_file.out");
+                unlink("$source_file.err");
+                unlink("$source_file");
+              }
           }
 
         }else{
@@ -513,7 +571,7 @@ sub handle_code {
           my $code_to_eval = join "\n", @$code;
           eval "package main; $code_to_eval";
           confess "eval error; sub:handle_code; code:\n$code_to_print\nerror: $@" if $@;
-          $self->add_debug_result("handle_code OK. multiline. $code_to_eval") if $self->{debug_mod} >= 3;
+          $self->add_debug_result("code OK. multiline. $code_to_eval") if $self->{debug_mod} >= 3;
 
         }
 
@@ -532,7 +590,7 @@ sub handle_validator {
         confess "eval error; sub:handle_validator; code:$code\nerror: $@" if $@;
         confess "not valid return from validator, should be ARRAYREF. got: @{[ref $r]}" unless ref($r) eq 'ARRAY' ;
         $self->add_result({ status => $r->[0] , message => $r->[1] });
-        $self->add_debug_result("handle_validator OK (status: $r->[0] message: $r->[1]). $code") if $self->{debug_mod} >= 2;
+        $self->add_debug_result("validator OK. single line. code: $code") if $self->{debug_mod} >= 2;
 
     } else {
         my $i = 0;
@@ -542,7 +600,7 @@ sub handle_validator {
         confess "eval error; sub:handle_validator; code:\n$code_to_print\nerror: $@" if $@;
         confess "not valid return from validator, should be ARRAYREF. got: @{[ref $r]}" unless ref($r) eq 'ARRAY' ;
         $self->add_result({ status => $r->[0] , message => $r->[1] });
-        $self->add_debug_result("handle_validator OK. multiline. $code_to_eval") if $self->{debug_mod} >= 2;
+        $self->add_debug_result("validator OK. multiline. code: $code_to_eval") if $self->{debug_mod} >= 2;
     }
 
 }
@@ -557,40 +615,81 @@ sub handle_generator {
         my $arr_ref = eval "package main; $code";
         confess "eval error; sub:handle_generator; code:$code\nerror: $@" if $@;
         confess "not valid return from generator, should be ARRAYREF. got: @{[ref $arr_ref]}" unless ref($arr_ref) eq 'ARRAY' ;
-        $self->add_debug_result("handle_generator OK. $code") if $self->{debug_mod} >= 3;
+        $self->add_debug_result("generator OK. single line. code: $code") if $self->{debug_mod} >= 3;
         $self->validate($arr_ref);
 
 
     } else {
 
       my $i = 0;
+
       my $code_to_print = join "\n", map { my $v=$_; $i++; "[$i] $v" }  @$code;
 
-        if ($code->[0]=~s/^!(.*)//){
+        if ($code->[0]=~s/^\!(.*)//){
   
           my $ext_runner = $1;
 
-          my ($fh, $source_file) = tempfile( DIR => '/tmp' );
+          my $language = (split /\\/, $ext_runner)[-1];
 
-          shift @$code;
+          if ($language eq 'perl'){
 
-          my $code_to_eval = join "\n", @$code;
+              shift @$code;
 
-          print $fh $code_to_eval;
-          close $fh;
+              my $code_to_eval = join "\n", @$code;
+              my $code_to_print = join "\n", map { my $v=$_; $i++; "[$i] $v" }  @$code;
 
-          system("$ext_runner $source_file 2>$source_file.err 1>$source_file.out");  
+              my $arr_ref = eval "package main; $code_to_eval";
 
-          $self->add_debug_result("handle_external_generator OK. source: $source_file") if $self->{debug_mod} >= 2;
+              confess "eval error; sub:handle_code; code:\n$code_to_print\nerror: $@" if $@;
+              confess "not valid return from generator, should be ARRAYREF. got: @{[ref $arr_ref]}" unless ref($arr_ref) eq 'ARRAY' ;
 
-          $self->add_debug_result("handle_external_generator OK. $code_to_eval") if $self->{debug_mod} >= 3;
+              $self->add_debug_result("generator OK. inline(perl). $code_to_eval") if $self->{debug_mod} >= 3;
 
-          $self->validate("$source_file.out");
-        
-          unless ($ENV{outth_dls_keep_ext_source_code}){
-            unlink("$source_file.out");
-            unlink("$source_file.err");
-            unlink("$source_file");
+              $self->validate($arr_ref);
+          
+          } else {
+
+              my $source_file = File::Temp->new( DIR => $self->{cache_dir} , UNLINK => 0 );
+    
+              shift @$code;
+    
+              my $code_to_eval = join "\n", @$code;
+    
+              open SOURCE_CODE, '>', $source_file or die "can't open source code file $source_file to write: $!";
+    
+              print SOURCE_CODE $code_to_eval;
+    
+              close SOURCE_CODE;
+    
+              if ($language eq 'bash'){
+  
+                if ($self->{languages}->{$language}){
+                  $ext_runner = "bash -c '".($self->{languages}->{$language})." && source $source_file'";
+                }else{
+                  $ext_runner = "bash -c 'source $source_file'";
+                }
+  
+              }else{
+                $ext_runner.= ' '.$self->{languages}->{$language} if $self->{languages}->{$language};
+                $ext_runner.=' '.$source_file;
+              }
+  
+              my $st = system("$ext_runner 2>$source_file.err 1>$source_file.out");  
+  
+              if ($st != 0){
+                confess "$ext_runner failed, see $source_file.err for detailes";
+              }
+    
+              $self->add_debug_result("generator OK. inline. $ext_runner") if $self->{debug_mod} >= 2;
+    
+              $self->validate("$source_file.out");
+            
+              unless ($ENV{outth_dls_keep_ext_source_code}){
+                unlink("$source_file.out");
+                unlink("$source_file.err");
+                unlink("$source_file");
+              }
+    
           }
 
         }else {
@@ -601,7 +700,7 @@ sub handle_generator {
           confess "eval error; sub:handle_generator; code:\n$code_to_print\nerror: $@" if $@;
           confess "not valid return from generator, should be ARRAYREF. got: @{[ref $arr_ref]}" unless ref($arr_ref) eq 'ARRAY' ;
 
-          $self->add_debug_result("handle_generator OK. multiline. $code_to_eval") if $self->{debug_mod} >= 3;
+          $self->add_debug_result("generator OK. multiline. $code_to_eval") if $self->{debug_mod} >= 3;
           $self->validate($arr_ref);
   
       }
@@ -640,7 +739,7 @@ sub handle_regexp {
 
     $self->reset_context if $reset_context; 
 
-    $self->add_debug_result("handle_regexp OK. $re") if $self->{debug_mod} >= 3;
+    $self->add_debug_result("regexp OK. $re") if $self->{debug_mod} >= 3;
 
 
 }
@@ -667,7 +766,7 @@ sub handle_within {
 
     $self->check_line($re, 'regexp', $m);
 
-    $self->add_debug_result("handle_within OK. $re") if $self->{debug_mod} >= 3;
+    $self->add_debug_result("within OK. $re") if $self->{debug_mod} >= 3;
     
 }
 
@@ -701,7 +800,7 @@ sub handle_plain {
 
     $self->reset_context if $reset_context; 
 
-    $self->add_debug_result("handle_plain OK. $l") if $self->{debug_mod} >= 3;
+    $self->add_debug_result("plain OK. $l") if $self->{debug_mod} >= 3;
 }
 
 
@@ -740,7 +839,7 @@ Language to validate text output.
 
 =head1 Install
 
-    cpanm Outthentic::DSL
+    $ cpanm Outthentic::DSL
 
 
 =head1 Informal introduction
@@ -1009,13 +1108,13 @@ Client is a external program using dsl API. Existed outthentic clients:
 
 =item *
 
-L<swat|https://github.com/melezhik/swat> - web application testing tool
+L<Swat|https://github.com/melezhik/swat> - web application testing tool
 
 
 
 =item *
 
-L<outthentic|https://github.com/melezhik/outthentic> - generic testing tool
+L<Outthentic|https://github.com/melezhik/outthentic> -  multipurpose scenarios framework
 
 
 
@@ -1026,7 +1125,7 @@ More clients wanted :) , please L<write me|mailto:melezhik@gmail.com> if you hav
 
 =head1 dsl code syntax
 
-Outthentic dsl code comprises following basic entities:
+Outthentic dsl code comprises following entities:
 
 =over
 
@@ -1058,12 +1157,12 @@ within    expressions
 
 =item *
 
-range     expressions
+asserts   expressions
 
 
 =item *
 
-validator expressions
+range     expressions
 
 
 =back
@@ -1084,7 +1183,7 @@ Blank lines
 
 =item *
 
-Perl expressions
+Code expressions
 
 
 
@@ -1094,6 +1193,12 @@ Generator expressions
 
 
 
+=item *
+
+Validator expressions
+
+
+
 =back
 
 
@@ -1312,18 +1417,18 @@ parser will remain in a `text block' mode till the end of the file, which is pro
 
 Dsl code:
 
-        begin:
-            here we begin
-            and till the very end of test
+    begin:
+        here we begin
+        and till the very end of test
     
-            we are in `text block` mode
+        we are in `text block` mode
 
 
-=head1 Perl expressions
+=head1 Code expressions
 
-Perl expressions are just a pieces of Perl code to I<get evaled> during parsing process. 
+Code expressions are just a pieces of 'some language code' you may inline and execute B<during parsing> process.
 
-This is how it works.
+By default, if I<language> is no set Perl language is assumed. Here is example:
 
 Dsl code:
 
@@ -1343,25 +1448,7 @@ Internally once dsl code gets parsed it is "turned" into regular Perl code:
     eval 'print "Lived a boy called Outthentic"';
     execute_check_expression("Lived a boy called Outthentic");
 
-One of the use case for Perl expressions is to store L<`captures'|#captures> data.
-
-Dsl code:
-
-    regexp: my name is (\w+) and my age is (\d+)
-    code: $main::data{name} = capture()->[0]; $main::data{age} = capture()->[1]; 
-    code: print $data->{name}, "\n";
-    code: print $data->{age}, "\n";
-
-Input text:
-
-    my name is Alexey and my age is 38
-
-Output:
-
-    Alexey
-    38
-
-Additional comments on perl expressions:
+When use Perl expressions be aware of:
 
 =over
 
@@ -1379,88 +1466,84 @@ Follow L<http://perldoc.perl.org/functions/eval.html|http://perldoc.perl.org/fun
 
 =back
 
+One may use other languages in code expressions. Use should use `here' document style ( see L<multiline expressions|#Multiline> section ) to insert your code and
+set shebang to define a language. Here are some examples:
 
-=head1 Validators
 
-Validator expressions like Perl expressions are just a piece of Perl code. 
+=head2 bash 
 
-Validators start with `validator:' marker
+    code:  <<HERE
+    !bash
+    
+    echo '# hello I am Outthentic'
+    HERE
 
-A Perl code inside validator block should I<return> array reference. Once code is executed a returned array structure
-treated as:
+
+=head2 ruby
+
+    code: <<CODE
+    !ruby
+    
+    puts '# hello I am Outthentic'
+    CODE
+
+
+=head1 Asserts
+
+Asserts are simple statements with one of two values : true|false, a second assert parameter is just a description.
+
+Dsl code
+
+    assert: 0 'this is not true'
+    assert: 1 'this is true'
+
+Asserts almost always are created dynamically with generators. See next section.
+
+
+=head1 Generators
 
 =over
 
 =item *
 
-first element - is a status number ( perl true or false )
+Generators is the way to I<generate new outthentic entries on the fly>.
+
 
 
 =item *
 
-second element - is a helpful message 
+Generator expressions like code expressions are just a piece of code to be executed.
+
+
+
+=item *
+
+The only requirement for generator code - it should return I<new outthentic entities>.
+
+
+
+=item *
+
+If you use Perl in generator expressions ( which is by default ) - last statement in your
+code should return reference to array of strings. Strings in array would I<represent> a I<new> outthentic entities.
+
+
+
+=item *
+
+If you use not Perl language in generator expressions to produce new outthentic entities you should print them
+into B<stdout>. See examples below.
+
+
+
+=item *
+
+A new outthentic entries are passed back to parser and executed immediately.
+
 
 
 =back
 
-Validators a kind of check expressions with check logic I<expressed> in validator code.
-
-Examples.
-
-Dsl code:
-
-    # this is always true
-    validator: [ 10>1 , 'ten is bigger then one' ]
-    
-    # and this is not
-    validator: [ 1>10, 'one is bigger then ten'  ]
-    
-    # this one depends on previous check
-    regexp: credit card number: (\d+)
-    validator: [ captures()->[0]-[0] == '0101010101', 'I know your secrets!'  ]
-    
-    
-    # and this could be any
-    validator: [ int(rand(2)) > 1, 'I am lucky!'  ]
-
-Validators are very efficient when gets combined with L<`captures expressions'|#captures>
-
-This is a simple example.
-
-Input text:
-
-    # my family ages list
-    alex    38
-    julia   32
-    jan     2
-
-Dsl code:
-
-    # let's capture name and age chunks
-    regexp: /(\w+)\s+(\d+)/
-    
-    validator: <<CODE
-    my $total=0;                        
-    for my $c (@{captures()}) {         
-        $total+=$c->[0];                
-    }                                   
-    [ ( $total == 72 ), "total age" ] 
-    
-    CODE
-
-
-=head1 Generators
-
-Generators is the way to I<generate new outthentic entries on the fly>.
-
-Generator expressions like Perl expressions are just a piece of Perl code.
-
-The only requirement for generator code - it should return I<reference to array of strings>.
-
-Strings in array returned by generator code I<represent> a I<new> outthentic entities.
-
-A new outthentic entries are passed back to parser and executed immediately.
-
 Generators expressions start with `:generator' marker.
 
 Here is simple example.
@@ -1474,19 +1557,40 @@ Dsl code:
      
     # this generator creates 3 new check expressions:
     
-    generator: [ qw{ say hello again } ]
+    generator: <<CODE
+    [ 
+      'say', 
+      'hello', 
+      'again'
+    ]
+    CODE
 
-New dsl code:
+Updated check list:
 
-    # final check list:
-    
     Say
     HELLO
     say
     hello
     again
 
-Here is more complicated example.
+If you use not Perl in generator expressions, you have to print entries into stdout instead of returning
+and array reference like in Perl. Here is more examples for other languages:
+
+    generator: <<CODE
+    !bash
+      echo say
+      echo hello
+      echo again
+    CODE
+    
+    generator: <<CODE
+    !ruby
+      puts 'say'
+      puts 'hello'
+      puts 'again'
+    CODE
+
+Here is more complicated example using Perl.
 
 Dsl code:
 
@@ -1495,18 +1599,25 @@ Dsl code:
     # and plain string check expressions:
     
     generator: <<CODE    
-    my %d = { 'foo' => 'foo value', 'bar' => 'bar value' };     
-    [ map  { ( "# $_", "$data{$_}" )  } keys %d ]
+    my %d = { 
+      'foo' => 'foo value', 
+      'bar' => 'bar value' 
+    };     
+    [ 
+      map  { 
+        ( "# $_", "$data{$_}" )  
+      } keys %d 
+    ]
     CODE
 
-New dsl code:
+Updated check list:
 
     # foo
     foo value
     # bar
     bar value
 
-Generators could produce not only check expressions but validators, perl expressions and ... generators.
+Generators could produce not only check expressions but code expressions and ... another generators.
 
 This is fictional example.
 
@@ -1532,7 +1643,94 @@ Dsl code:
     }
     CODE
 
-Result - verified
+Generators are commonly used to create an asserts.
+
+Input:
+
+    number: 10
+
+Dsl code:
+
+    number: (\d+)
+    
+    generator: <<CODE
+    !ruby
+      puts "assert: #{capture()[0] == 10}, you've got 10!"  
+    CODE
+
+
+=head1 Validators
+
+WARNING!!! You should prefer asserts over validators. Validators feature will be deprecated soon!
+
+Validator expressions are perl code expressions used for dynamic verification.
+
+Validator expressions start with `validator:' marker.
+
+A Perl code inside validator block should I<return> array reference. 
+
+=over
+
+=item *
+
+Once code is executed a returned array structure treated as:
+
+
+
+=item *
+
+first element - is a status number ( Perl true or false )
+
+
+
+=item *
+
+second element - is a helpful message 
+
+
+
+=back
+
+Validators a kind of check expressions with check logic I<expressed> in program code. Here is examples:
+
+Dsl code:
+
+    # this is always true
+    validator: [ 10>1 , 'ten is bigger then one' ]
+    
+    # and this is not
+    validator: [ 1>10, 'one is bigger then ten'  ]
+    
+    # this one depends on previous check
+    regexp: credit card number: (\d+)
+    validator: [ captures()->[0]-[0] == '0101010101', 'I know your secrets!'  ]
+    
+    
+    # and this could be any
+    validator: [ int(rand(2)) > 1, 'I am lucky!'  ]
+
+Validators are often used with the L<`captures expressions'|#captures>. This is another example.
+
+Input text:
+
+    # my family ages list
+    alex    38
+    julia   32
+    jan     2
+
+Dsl code:
+
+    # let's capture name and age chunks
+    regexp: /(\w+)\s+(\d+)/
+    
+    validator: <<CODE
+    my $total=0;                        
+    for my $c (@{captures()}) {         
+        $total+=$c->[0];                
+    }                                   
+    [ ( $total == 72 ), "total age" ] 
+    
+    CODE
 
 
 =head1 Multiline expressions
@@ -1591,7 +1789,7 @@ Results:
 Use text blocks if you want to I<represent> multiline checks.
 
 
-=head2 Multilines in perl expressions, validators and generators
+=head2 Multilines in code expressions, generators and validators
 
 Perl expressions, validators and generators could contain multilines expressions
 
@@ -1989,19 +2187,19 @@ Dsl code:
 
 Output:
 
-        # foo/bar start
-        # 1
-        # 2
-        # 3
-        # 100
-        # foo/bar end
+    # foo/bar start
+    # 1
+    # 2
+    # 3
+    # 100
+    # foo/bar end
     
-        # FOO/BAR start
-        # 100
-        # 10
-        # 20
-        # 30
-        # FOO/BAR end
+    # FOO/BAR start
+    # 100
+    # 10
+    # 20
+    # 30
+    # FOO/BAR end
 
 
 =head2 Restoring search context
@@ -2035,8 +2233,7 @@ Dsl code:
 
 =head2 Range expressions caveats
 
-
-=head3 Range expressions can't verify continuous lists.
+Range expressions can't verify continuous lists.
 
 That means range expression only verifies that there are I<some set> of lines inside some range.
 It is not necessary should be continuous.
@@ -2230,55 +2427,6 @@ Output:
     # 0 0 0
 
 
-=head2 Inline code from other languages
-
-WARNING!!! Don't use these features in production unless this message is removed.
-
-One may use various languages in code and generators expressions. Here are examples.
-
-
-=head3 bash 
-
-    generator:  <<HERE
-    
-    !/bin/bash
-    echo OK
-    
-    HERE
-    
-    code: <<HERE
-    mkdir -p /tmp/foo   
-    HERE
-
-
-=head3 perl6
-
-    generator: <<PERL6
-    
-    !/usr/bin/perl6
-    
-    say 'OK';
-    
-    PERL6
-
-
-=head3 ruby
-
-    generator:  <<CODE
-    !/usr/bin/ruby
-    
-    puts 'OK'
-    
-    CODE
-    
-    generator:  <<<CODE
-    !ruby
-    
-    puts 'OK'
-    
-    CODE
-
-
 =head1 Author
 
 L<Aleksei Melezhik|mailto:melezhik@gmail.com>
@@ -2307,7 +2455,7 @@ Alternative outthentic dsl introduction could be found here - L<intro.md|https:/
 
 =item *
 
-to God as - I<For the LORD giveth wisdom: out of his mouth cometh knowledge and understanding. (Proverbs 2:6)>
+To God as the One Who inspires me to do my job!
 
 
 =back
